@@ -34,12 +34,28 @@ namespace Nepomuk2 {
         BackupGenerationJob(Soprano::Model *model, const QUrl& url, QObject* parent = 0);
         virtual void start();
 
+        enum Filter {
+            Filter_None,
+            Filter_TagsAndRatings
+        };
+
+        void setFilter(Filter filter);
     private slots:
         void doWork();
 
+        void slotResourceListProgress(KJob* job, ulong progress);
+        void slotResourceListFinished(KJob* job);
+
+        void slotStatementListGeneratorProgress(KJob* job, ulong progress);
+        void slotStatementListGenerationFinished(KJob* job);
+
+        void slotGraphGeneratorProgress(KJob* job, ulong progress);
+        void slotGraphGenerationFinished(KJob* job);
     private:
         Soprano::Model* m_model;
         QUrl m_url;
+
+        Filter m_filter;
     };
 }
 
