@@ -39,6 +39,7 @@
 #include <KNotification>
 #include <KIcon>
 #include <KIO/DeleteJob>
+#include <kdbusconnectionpool.h>
 
 #include <QtCore/QTimer>
 #include <QtCore/QFile>
@@ -194,7 +195,7 @@ void Nepomuk2::Repository::open()
     }
 
     // We accept virtuoso version 6.1.6+ Nepomuk hasn't really been tested with 7
-    QRegExp regex("(6\.1\.[6789])");
+    QRegExp regex("(6\\.1\\.[6789])");
     if( !m_virtuosoVersion.contains(regex) ) {
         kError() << "NepomukStorage only works with virtuoso 6.1.6 and beyond";
         return;
@@ -379,7 +380,7 @@ void Nepomuk2::Repository::openPublicInterface()
 
     m_dataManagementAdaptor = new Nepomuk2::DataManagementAdaptor(m_dataManagementModel);
 
-    QDBusConnection con = QDBusConnection::sessionBus();
+    QDBusConnection con = KDBusConnectionPool::threadConnection();
     con.registerObject(QLatin1String("/datamanagement"), m_dataManagementAdaptor,
                        QDBusConnection::ExportScriptableContents);
 }
